# -*- coding: utf-8 -*-
"""
Loads spreadsheet of data from emon (cut and paste from web interface)
plots as step data

"""
import pandas as pd
import matplotlib.pyplot as plt
import matplotlib.dates as mdates
import numpy as np


data_directory='/home/<PATH TO YOUR DATA>/'
data_file_name='heating_valves_example_data.xlsx'

#read from excel
state_data_df=pd.read_excel(data_directory+data_file_name, sheet_name='valves')

#generate date time index
state_data_df['Date-time string']=pd.to_datetime(state_data_df['Date-time string'],format='%Y-%b-%d %H:%M')
state_data_df.set_index('Date-time string',inplace=True)

#replace ' null' with na (note the leading space in excel fields as string)
state_data_df['heating:central_heat']=state_data_df['heating:central_heat'].replace([' null'],np.nan)

state_data_df['heating:pump_run']=state_data_df['heating:pump_run'].replace([' null'],np.nan)
state_data_df['heating:pump_run']=state_data_df['heating:pump_run']*1


#fill forward the vlaues 0 and 1 - this can miss upto the first 10 mins of data if a point is not written
#for now work round this by taking a bigger data period than we need
state_data_df.fillna(method='ffill',inplace=True)
state_data_df.dropna(inplace=True)

fig,ax=plt.subplots()
plt.xlabel('Date-Time',fontsize=12)
plt.ylabel('Closed/Stop | Open/Run',fontsize=12)

ax.plot(state_data_df.index,state_data_df['heating:central_heat'],color='red',linestyle='-',marker='',label='CH-Valve')
ax.plot(state_data_df.index,state_data_df['heating:pump_run'],color='blue',linestyle='-',marker='',label='Pump')

ax.xaxis.set_major_formatter(mdates.DateFormatter("%H:%M"))
ax.xaxis.set_minor_formatter(mdates.DateFormatter("%H:%M"))
plt.title('Valve Status - central heating')
plt.grid()
plt.legend()

save_filename=data_file_name.replace('.xlsx','.png')
plt.savefig(data_directory+save_filename+'.png')

